============
Authors
============

* Stanislav Prokopyev <stas.prokopiev@gmail.com>

Contacts
========

    * email: stas.prokopiev@gmail.com

    * `vk.com <https://vk.com/stas.prokopyev>`_

    * `Facebook <https://www.facebook.com/profile.php?id=100009380530321>`_